package com.jinhaiqimeng.sysManageMicroservice.util;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.jinhaiqimeng.sysManageMicroservice.result.ResponseResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

/**
 * @author cxt
 * @date 2023-10-19 13:50
 */
@Component
@Slf4j
public class EnumSensitiveWordValidator implements ConstraintValidator<EnumSensitiveWord, String> {
    @Autowired
    ContentAuditingMicroservice contentAuditingMicroservice;

    private int type;
    @Override
    public void initialize(EnumSensitiveWord constraintAnnotation) {
        this.type = constraintAnnotation.type();
    }

    @Override
    public boolean isValid(String value, ConstraintValidatorContext context) {
        if (StrUtil.isBlank(value)){
            return  true;
        }
        PartMatchDTO partMatchDTO = new PartMatchDTO();
        partMatchDTO.setContent(value);
        partMatchDTO.setPartMatch(false);
        if (1 == type){
            ResponseResult<SensitiveWordsVO> responseResult = contentAuditingMicroservice.matchSensitiveWord(partMatchDTO);
            if (responseResult.isFail()){
                log.error("调用敏感词服务失败!"+responseResult.getMsg());
                return true;
            } else {
                SensitiveWordsVO data1 = responseResult.getData();
                if (CollUtil.isEmpty(data1.getSensitiveWords())){
                    return true;
                }
                context.disableDefaultConstraintViolation();//禁用默认的message的值
                context.buildConstraintViolationWithTemplate("文本包含敏感词为:"+ JSON.toJSONString(data1.getSensitiveWords())).addConstraintViolation();
                return false;
            }
        } else if (2 == type){
            ResponseResult responseResult = contentAuditingMicroservice.containsSensitiveWord(partMatchDTO);
            if (responseResult.isFail()){
                log.error("调用敏感词服务失败!"+responseResult.getMsg());
                return true;
            } else {
                boolean data1 = (boolean)responseResult.getData();
                return !data1;
            }
        }
        return false;
    }
}
